#!/bin/bash
#by Wiboon Warasittichai, last updated 27-11-62
#
if [ -z "$(id -nG|grep -w "root")" ]; then
  echo "need root access, try: sudo bash $0"
  exit
fi

#get current working directory
cwd="$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)"

TEMPFILE=/tmp/01-netcfg.yaml.$$
NETNAME=$(cat ${HOME}/netname)
NETCONFIGFILE=/etc/netplan/01-netcfg.yaml
clear
echo
echo "Setting server IP in ${NETCONFIGFILE} using default template"
echo
cat << EOF
Example: 
CIDR notation 192.168.6.20/24 is IP 192.168.6.20 on subnet 192.168.6.0 netmask 255.255.255.0
CIDR notation 192.168.6.20/25 is IP 192.168.6.20 on subnet 192.168.6.0 netmask 255.255.255.128
------------------------ default template ----------------------------------------------------
# This file describes the network interfaces available on your system
# For more information, see netplan(5).
#
network:
  version: 2
  renderer: networkd
  ethernets:
    ${NETNAME}:
      addresses: [ 192.168.6.20/25 ]
      gateway4: 192.168.6.1
      nameservers:
          addresses:
              - 192.100.77.10
              - 192.100.77.11
----------------------------------------------------------------------------------------------
EOF
echo "Press any key to continue setting server IP in ${NETCONFIGFILE}"
read -p "Press x to exit. " akey

if [ "$akey" = "x" ]; then
  echo
  echo Do nothing.
  echo
  exit
fi

while true
do
echo
cat << EOF
==============================================================================================
Enter v1 - v5 for editing ${NETCONFIGFILE}
addresses (v1/v2), gateway4 (v3), nameservers (v4,v5)
==============================================================================================
network:
  version: 2
  renderer: networkd
  ethernets:
    ${NETNAME}:
EOF
echo -e "      addresses: [ \033[1;33mv1\033[0m/\033[1;33mv2\033[0m ]"
echo -e "      gateway4: \033[1;33mv3\033[0m"
echo -e "      nameservers:"
echo -e "          addresses:"
echo -e "              - \033[1;33mv4\033[0m"
echo -e "              - \033[1;33mv5\033[0m"
cat << EOF
==============================================================================================
EOF
echo -n "Enter server IP address (v1): "
read v1
echo -n "Enter CIDR notation (1-32) (v2): "
read v2
echo -n "Enter gateway4 (v3): "
read v3
echo -n "Enter nameserver IP address #1 (v4): "
read v4
echo -n "Enter nameserver IP address #2 (v5): "
read v5
echo
echo "Finished"
echo 
echo "---------------------------------------------------------------------"
echo "See that what you enter in ${NETCONFIGFILE}"
echo "---------------------------------------------------------------------"
cat << EOF | tee ${TEMPFILE}
# This file describes the network interfaces available on your system
# For more information, see netplan(5).
#
network:
  version: 2
  renderer: networkd
  ethernets:
    ${NETNAME}:
      addresses: [ $v1/$v2 ]
      gateway4: $v3
      nameservers:
          addresses:
              - $v4
              - $v5
EOF
echo "---------------------------------------------------------------------"
while true; do
  echo
  echo -n "Are you sure to save this configuration "
  read -p "(y/n) " AKEY
  case ${AKEY} in
    [Yy]*) ANS="YES" ; break ;;
    [Nn]*) ANS="NO" ; break ;;
    *) echo "Please answer y or n." ;;
  esac
done
if [ "${ANS}" = "NO" ]; then
  continue
else
  mkdir -p $cwd/backupfile
  sudo cp -p ${NETCONFIGFILE} $cwd/backupfile/01-netcfg.yaml.$(date +%F-%H%M%S)
  sudo cp -p ${TEMPFILE} ${NETCONFIGFILE}
  rm -f ${TEMPFILE}
fi
echo "sudo netplan apply"
sudo netplan apply
retStr=$?
if [ ! "$retStr" == 0 ]; then
  echo 
  echo "Error in ${NETCONFIGFILE}"
  read -p "press any key to re-enter again" akey
  echo 
else
  echo "Networking is started successfully."
  echo
  exit 
fi
done

